package com.knauf.ejb.stateless;

import java.rmi.RemoteException;
import javax.ejb.EJBObject;

/**
 * Remote Interface fr Geometric Model EJB.
 * 
 * @author  Wolfgang Knauf
 */

public interface GeometricModel extends EJBObject
{
  /**Berechen des Volumens eines Quaders.
   * @param a Lnge der Seite a, > 0
   * @param b Lnge der Seite b, > 0
   * @param c Lnge der Seite c, > 0
   * @return Das Volumen des Quaders = a * b * c
   * @exception IllegalArgumentException Falls a oder b oder c <= 0 ist.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public double computeCuboidVolume(double a, double b, double c) throws InvalidParameterException, RemoteException;

  /**Berechen der Oberflche eines Quaders.
   * @param a Lnge der Seite a, > 0
   * @param b Lnge der Seite b, > 0
   * @param c Lnge der Seite c, > 0
   * @return Die Oberflche des Quaders = 2 * (a * b) + 2 * (b*c) + 2 * (a * c)
   * @exception IllegalArgumentException Falls a oder b oder c <= 0 ist.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public double computeCuboidSurface(double a, double b, double c) throws InvalidParameterException, RemoteException;
}