package com.knauf.ejb.stateless;

import java.util.logging.Logger;
import javax.ejb.CreateException;
import javax.ejb.SessionBean;
import javax.ejb.SessionContext;

/**
 * Die eigentliche EJB (eine Stateless Session Bean mit
 * zwei Geschftsmethoden).
 * 
 * @author  Wolfgang Knauf
 */

public class GeometricModelBean implements SessionBean
{
  /**Der Session-Context der Bean */
  private SessionContext sessionContext = null;

  /**Der Logger, ist eine static Konstante (static Variablen mssen final sein !) */
  private static final Logger logger = Logger.getLogger(GeometricModelBean.class.getName());

  /**Konstruktor. Nothing special
   *
   */
  public GeometricModelBean()
  {
  }

  ////////////////////////////////////////////////////////////////////
  //          Methoden aus Interface SessionBean                    //
  ////////////////////////////////////////////////////////////////////

  /**Setzen des SessionContexts.
   * @param ctx Der neue Session Context.
   */
  public void setSessionContext(SessionContext ctx)
  {
    logger.info("setSessionContext");
    this.sessionContext = ctx;
  }

  /**Passivieren der Bean. Nix zu tun
   *
   */
  public void ejbPassivate()
  {
    logger.info("passivate GeometricModelBean");
  }

  /**Aktivieren der Bean. Nix zu tun
   *
   */
  public void ejbActivate()
  {
    logger.info("activate GeometricModelBean");
  }

  /**Entfernen der Bean. Nichts zu tun.
   *
   */
  public void ejbRemove()
  {
    logger.info("remove GeometricModelBean");
  }

  ///////////////////////////////////////////////////////////////////
  //         Methoden aus Home-Interface                           //
  ///////////////////////////////////////////////////////////////////

  /**Create. Stammt aus den Home-Interfaces.
   * @exception CreateException Fehler beim Erzeugen.
   */
  public void ejbCreate() throws javax.ejb.CreateException
  {
    logger.info("create GeometricModelBean");
  }

  ///////////////////////////////////////////////////////////////////
  //           Methoden aus Remote-Interface                       //
  ///////////////////////////////////////////////////////////////////

  /**Berechen des Volumens eines Quaders.
   * @param a Lnge der Seite a, > 0
   * @param b Lnge der Seite b, > 0
   * @param c Lnge der Seite c, > 0
   * @return Das Volumen des Quaders = a * b * c
   * @exception InvalidParameterException Falls a oder b oder c <= 0 ist.
   */
  public double computeCuboidVolume(double a, double b, double c) throws InvalidParameterException
  {
    if (a <= 0 || b <= 0 || c <= 0)
      throw new InvalidParameterException("Seitenlnge <= 0");

    return a * b * c;
  }

  /**Berechen der Oberflche eines Quaders.
   * @param a Lnge der Seite a, > 0
   * @param b Lnge der Seite b, > 0
   * @param c Lnge der Seite c, > 0
   * @return Die Oberflche des Quaders = 2 * (a * b) + 2 * (b*c) + 2 * (a * c)
   * @exception InvalidParameterException Falls a oder b oder c <= 0 ist.
   */
  public double computeCuboidSurface(double a, double b, double c) throws InvalidParameterException
  {
    if (a <= 0 || b <= 0 || c <= 0)
      throw new InvalidParameterException("Seitenlnge <= 0");

    return 2 * (a * b + b * c + c * a);
  }
}